% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/filterSignature.R
\name{filterSignature}
\alias{filterSignature}
\title{Filter the L1000 Signature
\ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#stable}{\figure{lifecycle-stable.svg}{options: alt='[Stable]'}}}{\strong{[Stable]}}}
\usage{
filterSignature(signature, direction = "any", threshold = NULL, prop = NULL)
}
\arguments{
\item{signature}{A dataframe with the L1000 signature}

\item{direction}{Direction to filter to. Must be one of "up",
"down" or "any". Defaults to "any"}

\item{threshold}{A Log Fold-Change Threshold to filter at.
This can either be a single value or a vector of two values.
If a single value is given, then it is assumed to be a symmetric threshold.
If two values are given, then the first value is the down-regulated
threshold and the second value is
the up-regulated threshold. Cannot be specified with prop}

\item{prop}{A proportion of genes to take from top and bottom.
Cannot be specified with threshold}
}
\value{
a tibble with the filtered L1000 Signature
}
\description{
This function filters the L1000 Signature to a given threshold, identifying
up-regulated or down-regulated or both up- and down-regulated genes
}
\examples{
# Get the L1000 signature for LINCSKD_28
kdSignature <- getSignature("LINCSKD_28")

# Filter signature by a specific threshold
filteredSignature <- filterSignature(kdSignature, threshold = 0.5)

# Filter signature by a proportion

filteredSignature <- filterSignature(kdSignature, prop = 0.1)

# Filter Signature to up-regulated genes only by a threshold

filteredSignature <- filterSignature(kdSignature,
    direction = "up", threshold = 0.5
)

# Filter the signature using differing thresholds for up and
# down-regulated genes

filteredSignature <- filterSignature(kdSignature,
    threshold = c(-0.75, 0.5)
)
}
