% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prepareSignature.R
\name{prepareSignature}
\alias{prepareSignature}
\title{Prepare an L1000 Signature froma given differential gene expression output
\ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#stable}{\figure{lifecycle-stable.svg}{options: alt='[Stable]'}}}{\strong{[Stable]}}}
\usage{
prepareSignature(
  dge,
  geneColumn = "Symbol",
  logfcColumn = "logFC",
  pvalColumn = "PValue"
)
}
\arguments{
\item{dge}{A dataframe-like object that has the differential
gene expression information}

\item{geneColumn}{The name of the column that has gene symbols}

\item{logfcColumn}{The name of the column that has log_2 fold-change values}

\item{pvalColumn}{The name of the column that has p-values}
}
\value{
A tibble with the L1000 signature.
}
\description{
This function takes a differential gene expression output from any pipeline
like edgeR or DeSeq2 or any that give you the gene symbol,
log_2 fold-change and p-value
and transforms that into an L1000 signature for later processing.
}
\examples{
# Prepare an L1000 signature from a differential gene expression output

inputSignature <- read.table(system.file("extdata",
    "dCovid_diffexp.tsv",
    package = "drugfindR"
), header = TRUE)

signature <- prepareSignature(inputSignature,
    geneColumn = "hgnc_symbol",
    logfcColumn = "logFC", pvalColumn = "PValue"
)

head(signature)
}
